aboutsummaryrefslogtreecommitdiff
path: root/src-qt5
diff options
context:
space:
mode:
Diffstat (limited to 'src-qt5')
-rw-r--r--src-qt5/core/libLumina/LuminaOS-FreeBSD.cpp8
-rw-r--r--src-qt5/core/lumina-desktop/AppMenu.cpp2
-rw-r--r--src-qt5/core/lumina-desktop/audiofiles/LICENCE2
-rw-r--r--src-qt5/core/lumina-desktop/lumina-desktop.pro2
-rw-r--r--src-qt5/core/lumina-desktop/panel-plugins/appmenu/LAppMenuPlugin.cpp2
-rw-r--r--src-qt5/core/lumina-info/MainUI.ui2
-rw-r--r--src-qt5/core/lumina-wm-INCOMPLETE/DEPENDENCIES2
7 files changed, 10 insertions, 10 deletions
diff --git a/src-qt5/core/lumina-desktop/AppMenu.cpp b/src-qt5/core/lumina-desktop/AppMenu.cpp
index 0b8aeace..ad3a2695 100644
--- a/src-qt5/core/lumina-desktop/AppMenu.cpp
+++ b/src-qt5/core/lumina-desktop/AppMenu.cpp
@@ -9,7 +9,7 @@
#include <LuminaOS.h>
AppMenu::AppMenu(QWidget* parent) : QMenu(parent){
- appstorelink = LOS::AppStoreShortcut(); //Default application "store" to display (AppCafe in PC-BSD)
+ appstorelink = LOS::AppStoreShortcut(); //Default application "store" to display (AppCafe in TrueOS)
controlpanellink = LOS::ControlPanelShortcut(); //Default control panel
APPS.clear();
watcher = new QFileSystemWatcher(this);
diff --git a/src-qt5/core/lumina-desktop/audiofiles/LICENCE b/src-qt5/core/lumina-desktop/audiofiles/LICENCE
index 2929216f..898894f6 100644
--- a/src-qt5/core/lumina-desktop/audiofiles/LICENCE
+++ b/src-qt5/core/lumina-desktop/audiofiles/LICENCE
@@ -1 +1 @@
-These audio files are BSD-licensed and were created/owned by the PC-BSD Project
+These audio files are BSD-licensed and were created/owned by the TrueOS Project
diff --git a/src-qt5/core/lumina-desktop/lumina-desktop.pro b/src-qt5/core/lumina-desktop/lumina-desktop.pro
index 5169476c..33c20502 100644
--- a/src-qt5/core/lumina-desktop/lumina-desktop.pro
+++ b/src-qt5/core/lumina-desktop/lumina-desktop.pro
@@ -87,7 +87,7 @@ defaults.path = $${L_SHAREDIR}/lumina-desktop/
conf.path = $${L_ETCDIR}
-#Now do any PC-BSD defaults (if set)
+#Now do any TrueOS defaults (if set)
PCBSD{
conf.extra = cp defaults/luminaDesktop.pcbsd.conf $(INSTALL_ROOT)$${L_ETCDIR}/luminaDesktop.conf.dist
defaults.extra = cp defaults/desktop-background.pcbsd.jpg $(INSTALL_ROOT)$${L_SHAREDIR}/lumina-desktop/desktop-background.jpg
diff --git a/src-qt5/core/lumina-desktop/panel-plugins/appmenu/LAppMenuPlugin.cpp b/src-qt5/core/lumina-desktop/panel-plugins/appmenu/LAppMenuPlugin.cpp
index 57e84a1d..5d20e3ec 100644
--- a/src-qt5/core/lumina-desktop/panel-plugins/appmenu/LAppMenuPlugin.cpp
+++ b/src-qt5/core/lumina-desktop/panel-plugins/appmenu/LAppMenuPlugin.cpp
@@ -36,7 +36,7 @@ LAppMenuPlugin::~LAppMenuPlugin(){
void LAppMenuPlugin::updateButtonVisuals(){
button->setToolTip( tr("Quickly launch applications or open files"));
button->setText( tr("Applications") );
- //Use the PC-BSD icon by default (or the Lumina icon for non-PC-BSD systems)
+ //Use the TrueOS icon by default (or the Lumina icon for non-TrueOS systems)
button->setIcon( LXDG::findIcon("start-here-lumina","Lumina-DE") );
}
diff --git a/src-qt5/core/lumina-info/MainUI.ui b/src-qt5/core/lumina-info/MainUI.ui
index 175497bd..f30d0e04 100644
--- a/src-qt5/core/lumina-info/MainUI.ui
+++ b/src-qt5/core/lumina-info/MainUI.ui
@@ -356,7 +356,7 @@
</property>
<item>
<property name="text">
- <string notr="true">PC-BSD</string>
+ <string notr="true">TrueOS</string>
</property>
<property name="toolTip">
<string notr="true">www.pcbsd.org</string>
diff --git a/src-qt5/core/lumina-wm-INCOMPLETE/DEPENDENCIES b/src-qt5/core/lumina-wm-INCOMPLETE/DEPENDENCIES
index 63b18ab7..fa0ce486 100644
--- a/src-qt5/core/lumina-wm-INCOMPLETE/DEPENDENCIES
+++ b/src-qt5/core/lumina-wm-INCOMPLETE/DEPENDENCIES
@@ -3,7 +3,7 @@ DEPENDENCIES file in the directory above this one. The following
are dependencies specific to Lumina's window manager.
-FreeBSD/PC-BSD
+FreeBSD/TrueOS
=======================
bgstack15
diff --git a/src-qt5/core/libLumina/LuminaOS-FreeBSD.cpp b/src-qt5/core/libLumina/LuminaOS-FreeBSD.cpp
index 0a544165..ab68361e 100644
--- a/src-qt5/core/libLumina/LuminaOS-FreeBSD.cpp
+++ b/src-qt5/core/libLumina/LuminaOS-FreeBSD.cpp
@@ -30,7 +30,7 @@ QString LOS::AppStoreShortcut(){ return "/usr/local/share/applications/appcafe.d
QStringList LOS::RSSFeeds(){
QStringList feeds;
feeds << "FreeBSD News Feed::::https://www.freebsd.org/news/rss.xml";
- feeds << "PC-BSD News Feed::::https://blog.pcbsd.org/?feed=rss2";
+ feeds << "TrueOS News Feed::::https://blog.pcbsd.org/?feed=rss2";
return feeds;
}
@@ -90,9 +90,9 @@ void LOS::setScreenBrightness(int percent){
else if(percent>100){ percent=100; }
//Run the command(s)
bool success = false;
// - try hardware setting first (PC-BSD || or intel_backlight)
if( LUtils::isValidBinary("pc-sysconfig") ){
//Use PC-BSD tool (direct sysctl control)
QString ret = LUtils::getCmdOutput("pc-sysconfig", QStringList() <<"setscreenbrightness "+QString::number(percent)).join("");
success = ret.toLower().contains("success");
qDebug() << "Set hardware brightness:" << percent << success;
@@ -216,7 +216,7 @@ void LOS::systemRestart(){ //start reboot sequence
//Check for suspend support
bool LOS::systemCanSuspend(){
//This will only function on PC-BSD
//(permissions issues on standard FreeBSD unless setup a special way)
bool ok = QFile::exists("/usr/local/bin/pc-sysconfig");
if(ok){
@@ -90,9 +90,9 @@ void LOS::setScreenBrightness(int percent){
//Run the command(s)
bool success = false;
- // - try hardware setting first (PC-BSD || or intel_backlight)
+ // - try hardware setting first (TrueOS || or intel_backlight)
if( LUtils::isValidBinary("pc-sysconfig") ){
@@ -90,9 +90,9 @@ void LOS::setScreenBrightness(int percent){
if( LUtils::isValidBinary("pc-sysconfig") ){
- //Use PC-BSD tool (direct sysctl control)
+ //Use TrueOS tool (direct sysctl control)
QString ret = LUtils::getCmdOutput("pc-sysconfig", QStringList() <<"setscreenbrightness "+QString::number(percent)).join("");
success = ret.toLower().contains("success");
@@ -216,7 +216,7 @@ void LOS::systemRestart(){ //start reboot sequence
//Check for suspend support
bool LOS::systemCanSuspend(){
- //This will only function on PC-BSD
+ //This will only function on TrueOS
//(permissions issues on standard FreeBSD unless setup a special way)
bool ok = QFile::exists("/usr/local/bin/pc-sysconfig");